require File.expand_path('../test_helper', __FILE__)

describe Elastomer::CLI::Snapshot do
  describe 'get' do
    it 'should get snapshot info' do
      VCR.use_cassette('snapshots') do
        elastomer 'snapshot get repo1 snapshot1'
        @out.must_match /snapshot1/
        @out.must_match /SUCCESS/
        @out.wont_match /snapshot2/
      end
    end
  end

  describe 'list' do
    it 'should list snapshots in a repository' do
      VCR.use_cassette('snapshots') do
        elastomer 'snapshot list repo1'
        @out.must_match /snapshot1.+SUCCESS/
        @out.must_match /snapshot2.+SUCCESS/
      end
    end
  end

  describe 'status' do
    it 'should get snapshot status' do
      VCR.use_cassette('snapshots') do
        elastomer 'snapshot status repo1 snapshot2'
        @out.must_match /STATUS.+snapshot2/
        @out.must_match /Repository.+repo1/
        @out.must_match /State.+SUCCESS/
        @out.must_match /Start Time.+2014-12-10/
        @out.must_match /Duration.+0.001s/
        @out.must_match /Processed Files.+100.0% \(1 \/ 1\)/
        @out.must_match /Processed Bytes.+100.0% \(79 \/ 79\)/
        @out.must_match /Shard Status.+1 done/
        @out.must_match /Shards Failed.+0/
        @out.must_match /Total Shards.+1/
        @out.must_match /Total Indices.+1/
      end
    end

    it 'should get snapshot status in progress' do
      VCR.use_cassette('snapshots') do
        elastomer 'snapshot status repo1 snapshot3'
        @out.must_match /STATUS.+snapshot3/
        @out.must_match /Repository.+repo1/
        @out.must_match /State.+STARTED/
        # Start time and total duration are broken in ES 1.2 for in-progress
        # snapshots
        # @out.must_match /Start Time.+2014-12-10/
        # @out.must_match /Duration.+0.001s/
        @out.must_match /Processed Files.+84.3% \(188 \/ 223\)/
        @out.must_match /Processed Bytes.+10.2% \(28461769 \/ 279913556\)/
        @out.must_match /Shard Status.+17 initializing, 1 started, 3 finalizing, 33 done/
        @out.must_match /Shards Failed.+0/
        @out.must_match /Total Shards.+54/
        @out.must_match /Total Indices.+1/
      end
    end
  end

  describe 'create' do
    it 'should create a snapshot' do
      VCR.use_cassette('snapshots') do
        elastomer 'snapshot create repo1 snapshot4 --indices index1'
        @out.must_match /accepted/
      end
    end

    it 'should wait for completion' do
      VCR.use_cassette('snapshots') do
        elastomer 'snapshot create repo1 snapshot3 --indices index1 --wait_for_completion'
        @out.must_match /^Waiting/m
        @out.must_match /snapshot3/
        @out.must_match /index1/
        @out.must_match /SUCCESS/
      end
    end
  end

  describe 'restore' do
    it 'should restore a snapshot' do
      VCR.use_cassette('snapshots') do
        elastomer "snapshot restore repo1 snapshot2 --indices index1 --rename_pattern (.+) --rename_replacement restored_$1"
        @status.must_equal nil
        @out.must_match /snapshot2/
        @out.must_match /restored_index1/
      end
    end
  end

  describe 'delete' do
    it 'should delete a snapshot' do
      VCR.use_cassette('snapshots') do
        elastomer 'snapshot delete repo1 snapshot1'
        @out.must_match /deleted snapshot1 in repo1/
      end
    end
  end
end
