require 'rubygems'
require 'bundler'

require 'minitest/autorun'
require 'webmock'
require 'vcr'

require 'elastomer/cli'

# Don't raise errors, test output instead
ENV['THOR_DEBUG'] = '0'

VCR.configure do |c|
  c.cassette_library_dir = File.expand_path('../fixtures/vcr_cassettes', __FILE__)
  c.hook_into :webmock
  c.default_cassette_options = {
    :match_requests_on => [:method, :path, :body],
  }
end

module CLITestSupport
  # Run the elastomer cli app in process and capture the output.
  #
  # argv - The list of arguments to the command. Can be specified as a string,
  #        a list of strings, or an array of strings. In the string form,
  #        arguments are split on spaces, so use the list or array form to
  #        preserve spaces.
  #
  # Examples
  #
  #   elastomer "foo bar"
  #   elastomer "foo", "bar with spaces"
  #   elastomer ["foo", "bar with spaces"]
  #
  # Returns the captured stdout and stderr content, and sets @out and @err with
  # the same content.
  def elastomer(*argv)
    argv = argv.flatten
    if argv.size == 1
      argv = argv.first.split(" ")
    end
    @out, @err = capture_io do
       Elastomer::CLI.start(argv)
     end
  end
end

class Minitest::Test
  include CLITestSupport
end
